pub fn render_agent_template(template: &str, config: &AgentConfig) -> StringExpand description
Render an agent template by replacing placeholders with actual values
pub fn render_agent_template(template: &str, config: &AgentConfig) -> StringRender an agent template by replacing placeholders with actual values