pub fn extract_managed_block(text: &str) -> Option<&str>Expand description
Extract the substring between ITO_START_MARKER and ITO_END_MARKER.
Returns None if the markers are not present on their own lines.
pub fn extract_managed_block(text: &str) -> Option<&str>Extract the substring between ITO_START_MARKER and ITO_END_MARKER.
Returns None if the markers are not present on their own lines.