render_project_template

Function render_project_template 

pub fn render_project_template(
    template_bytes: &[u8],
    ctx: &WorktreeTemplateContext,
) -> Result<Vec<u8>, Error>
Render a project template with the given worktree context.

If the template bytes are not valid UTF-8 or do not contain Jinja2 syntax ({% or {{), the bytes are returned unchanged. Otherwise the template is rendered through minijinja with ctx as the context.

Errors

Returns a minijinja::Error if the template contains Jinja2 syntax but fails to render (e.g., undefined variable in strict mode).