pub fn get_command_file(path: &str) -> Option<&'static [u8]>Expand description
Fetches the contents of an embedded command file by its path relative to the commands asset root.
Returns
Some(&[u8]) with the file contents if a file at path exists, None otherwise.
Examples
use ito_templates::get_command_file;
let contents = get_command_file("ito-apply.md");
if let Some(bytes) = contents {
assert!(!bytes.is_empty());
}